==> haskell-tomland-1.3.3.3-47-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tomland.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tomland
version:              1.3.3.3
visibility:           public
id:                   tomland-1.3.3.3-CdCYVKAaw6EHleRs0fkK6O
key:                  tomland-1.3.3.3-CdCYVKAaw6EHleRs0fkK6O
license:              MPL-2.0
copyright:            2018-2023 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Dmitrii Kovanikov, Veronika Romashkina
homepage:             https://github.com/kowainik/tomland
synopsis:             Bidirectional TOML serialization
description:
    Implementation of bidirectional TOML serialization. Simple codecs look like this:

    @
    __data__ User = User
    \    { userName :: Text
    \    , userAge  :: Int
    \    }
    \
    \userCodec :: TomlCodec User
    \userCodec = User
    \    \<$\> Toml.text "name" .= userName
    \    \<*\> Toml.int  "age"  .= userAge
    @

    The following blog post has more details about library design:

    * [tomland: Bidirectional TOML serialization](https://kowainik.github.io/posts/2019-01-14-tomland)

category:             TOML, Text, Configuration
abi:                  71c8fc30351efea036520a5a80a9230a
exposed:              True
exposed-modules:
    Toml Toml.Codec Toml.Codec.BiMap Toml.Codec.BiMap.Conversion
    Toml.Codec.Code Toml.Codec.Combinator Toml.Codec.Combinator.Common
    Toml.Codec.Combinator.Custom Toml.Codec.Combinator.List
    Toml.Codec.Combinator.Map Toml.Codec.Combinator.Monoid
    Toml.Codec.Combinator.Primitive Toml.Codec.Combinator.Set
    Toml.Codec.Combinator.Table Toml.Codec.Combinator.Time
    Toml.Codec.Combinator.Tuple Toml.Codec.Di Toml.Codec.Error
    Toml.Codec.Generic Toml.Codec.Types Toml.Parser Toml.Parser.Core
    Toml.Parser.Item Toml.Parser.Key Toml.Parser.String
    Toml.Parser.Validate Toml.Parser.Value Toml.Type Toml.Type.AnyValue
    Toml.Type.Edsl Toml.Type.Key Toml.Type.PrefixTree Toml.Type.Printer
    Toml.Type.TOML Toml.Type.UValue Toml.Type.Value

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tomland-1.3.3.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tomland-1.3.3.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tomland-1.3.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tomland
hs-libraries:         HStomland-1.3.3.3-CdCYVKAaw6EHleRs0fkK6O
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    hashable-1.4.4.0-Jc2uKL4S7Fl9QLNJZYpfiY
    megaparsec-9.6.1-KkOPmPbRCEmCvB2XbKT9En mtl-2.2.2
    parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav text-2.0.2
    time-1.12.2 unordered-containers-0.2.20-L3M6eILO3KM5ipeNJik2xY
    validation-selective-0.2.0.0-3dIiKItG2OE8jJob66vqcZ

haddock-interfaces:   /usr/share/doc/haskell-tomland/html/tomland.haddock
haddock-html:         /usr/share/doc/haskell-tomland/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tomland-1.3.3.3-48-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tomland.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tomland
version:              1.3.3.3
visibility:           public
id:                   tomland-1.3.3.3-65H5EXLIAl0LuMto1A0S1H
key:                  tomland-1.3.3.3-65H5EXLIAl0LuMto1A0S1H
license:              MPL-2.0
copyright:            2018-2023 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Dmitrii Kovanikov, Veronika Romashkina
homepage:             https://github.com/kowainik/tomland
synopsis:             Bidirectional TOML serialization
description:
    Implementation of bidirectional TOML serialization. Simple codecs look like this:

    @
    __data__ User = User
    \    { userName :: Text
    \    , userAge  :: Int
    \    }
    \
    \userCodec :: TomlCodec User
    \userCodec = User
    \    \<$\> Toml.text "name" .= userName
    \    \<*\> Toml.int  "age"  .= userAge
    @

    The following blog post has more details about library design:

    * [tomland: Bidirectional TOML serialization](https://kowainik.github.io/posts/2019-01-14-tomland)

category:             TOML, Text, Configuration
abi:                  4cdfefba697194489e413384d15c562e
exposed:              True
exposed-modules:
    Toml Toml.Codec Toml.Codec.BiMap Toml.Codec.BiMap.Conversion
    Toml.Codec.Code Toml.Codec.Combinator Toml.Codec.Combinator.Common
    Toml.Codec.Combinator.Custom Toml.Codec.Combinator.List
    Toml.Codec.Combinator.Map Toml.Codec.Combinator.Monoid
    Toml.Codec.Combinator.Primitive Toml.Codec.Combinator.Set
    Toml.Codec.Combinator.Table Toml.Codec.Combinator.Time
    Toml.Codec.Combinator.Tuple Toml.Codec.Di Toml.Codec.Error
    Toml.Codec.Generic Toml.Codec.Types Toml.Parser Toml.Parser.Core
    Toml.Parser.Item Toml.Parser.Key Toml.Parser.String
    Toml.Parser.Validate Toml.Parser.Value Toml.Type Toml.Type.AnyValue
    Toml.Type.Edsl Toml.Type.Key Toml.Type.PrefixTree Toml.Type.Printer
    Toml.Type.TOML Toml.Type.UValue Toml.Type.Value

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tomland-1.3.3.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tomland-1.3.3.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tomland-1.3.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tomland
hs-libraries:         HStomland-1.3.3.3-65H5EXLIAl0LuMto1A0S1H
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    hashable-1.4.4.0-7zzKXDBa1HP1F6vPi1Tvtg
    megaparsec-9.6.1-6qeEGREH0fMn1gOMY5ab1 mtl-2.2.2
    parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav text-2.0.2
    time-1.12.2 unordered-containers-0.2.20-66FGtARgHXEQRH0VfdDtx
    validation-selective-0.2.0.0-3eVynK0AwjFD1Iql3tQcdJ

haddock-interfaces:   /usr/share/doc/haskell-tomland/html/tomland.haddock
haddock-html:         /usr/share/doc/haskell-tomland/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
